local AddonName, a = ...
if a.BuildFail(50000) then return end
local L = a.Localize
local s = SpellFlashAddon
local x = s.UpdatedVariables
local _

-- SpellFlash API:
-- http://wow.curseforge.com/addons/spellflash/pages/api/

-- Updated variable references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-local-x-spell-flash-addon-updated-variables
-- x.Enemy, x.ActiveEnemy, x.NoCC, x.InInstance, x.InstanceType, x.PetAlive, x.PetActiveEnemy, x.PetNoCC, x.Lag, x.DoubleLag, x.ThreatPercent, x.EnemyDetected, x.ShouldPermanentBuff, x.ShouldTemporaryBuff

-- Spell table references:
-- http://wow.curseforge.com/addons/spellflash/pages/api/#w-s-castable

a.StatBuffs = {
	1126--[[Mark of the Wild]],
	115921--[[Legacy of the Emperor]],
	116781--[[Legacy of the White Tiger]],
	20217--[[Blessing of Kings]],
	90363--[[Embrace of the Shale Spider]],
	159988--[[Bark of the Wild]],
	160017--[[Blessing of Kongs]],
	90363--[[Embrace of the Shale Spider]],
	160077--[[Strength of the Earth]]
}

a.CritBuffs = {
	116781--[[Legacy of the White Tiger]],
	17007--[[Leader of the Pack]],
	1459--[[Arcane Brilliance]],
	61316--[[Dalaran Brilliance]],
	24604--[[Furious Howl]],
	90309--[[Terrifying Roar]],
	126373--[[Fearless Roar]],
	126309--[[Still Water]],
	160052--[[Strength of the Pack]],
	90363--[[Embrace of the Shale Spider]]
}

a.spells["auto_attack"] = {
	ID = 6603--[[Auto Attack]],
	EnemyTargetNeeded = 1,
	Melee = 1,
	NotIfActive = 1,
	CheckFirst = function(z)
		z.FlashColor = s.If(x.ActiveEnemy, "White", "Pink")
		return x.NoCC
	end,
}

a.spells["berserking,if=buff.tigereye_brew_use.up|target.time_to_die<18"] = {
	ID = 26297--[[Berserking]],
	NoRangeCheck = true,
	Check = function(z)
		return x.InCombat and x.ActiveEnemy and (x.BuffTigereyeBrewRemains > x.Lag or x.TimeToDie < 18)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["berserking,if=energy<=40"] = {
	ID = 26297--[[Berserking]],
	NoRangeCheck = true,
	Check = function(z)
		return x.InCombat and x.ActiveEnemy and x.Energy <= 40
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["blood_fury,if=buff.tigereye_brew_use.up|target.time_to_die<18"] = {
	ID = 33697--[[Blood Fury]],
	NoRangeCheck = true,
	Check = function(z)
		return x.InCombat and x.ActiveEnemy and (x.BuffTigereyeBrewRemains > x.Lag or x.TimeToDie < 18)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["blood_fury,if=energy<=40"] = {
	ID = 33697--[[Blood Fury]],
	NoRangeCheck = true,
	Check = function(z)
		return x.InCombat and x.ActiveEnemy and x.Energy <= 40
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["arcane_torrent,if=chi.max-chi>=1&(buff.tigereye_brew_use.up|target.time_to_die<18)"] = {
	ID = 129597--[[Arcane Torrent]],
	NoRangeCheck = true,
	Check = function(z)
		return x.InCombat and x.ActiveEnemy and x.MaxChi - x.Chi >= 1 and (x.BuffTigereyeBrewRemains > x.Lag or x.TimeToDie < 18)
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["arcane_torrent,if=energy<=40"] = {
	ID = 129597--[[Arcane Torrent]],
	NoRangeCheck = true,
	Check = function(z)
		return x.InCombat and x.ActiveEnemy and x.Energy <= 40
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["synapse_springs"] = {
	Type = "item",
	NoRangeCheck = true,
	Check = function(z)
		local gloves = GetInventoryItemID("player", 10)
		z.ID = gloves
		z.FlashID = gloves
		return x.InCombat and x.ActiveEnemy and s.ItemCooldown(gloves) == 0
	end,
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["potion,name=draenic_agility,if=buff.serenity.up|(!talent.serenity.enabled&trinket.proc.agility.react)"] = {
	Type = "item",
	ID = 109217--[[Draenic Agility Potion]],
	Buff = 156423--[[Draenic Agility Potion]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.ActiveEnemy and s.Boss("target")
	end,
	CheckLast = function(z)
		return x.BuffSerenityRemains > 0 or (not x.TalentSerenityEnabled and x.TrinketProcAgilityRemains > 0)
	end,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["potion,name=draenic_agility"] = {
	Type = "item",
	ID = 109217--[[Draenic Agility Potion]],
	Buff = 156423--[[Draenic Agility Potion]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss("target")
	end,
	FlashColor = "Yellow",
	Continue = true,
}

a.spells["purifying_brew,if=!talent.chi_explosion.enabled&stagger.heavy"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and x.Chi >= 1 and not x.TalentChiExplosionEnabled and s.BuffDuration(124273--[[Heavy Stagger]], "player", nil, false, false, true) > x.Lag
	end,
}

a.spells["purifying_brew,if=buff.serenity.up"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and x.Chi >= 1 and x.BuffSerenityRemains > x.Lag and a.getStagger() > 0
	end,
	Continue = true,
}

a.spells["purifying_brew,if=!talent.chi_explosion.enabled&stagger.moderate&buff.shuffle.remains>=6"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and x.Chi >= 1 and not x.TalentChiExplosionEnabled and s.BuffDuration(124274--[[Moderate Stagger]], "player", nil, false, false, true) > x.Lag and x.BuffShuffleRemains >= (6 + x.Lag)
	end,
}

a.spells["purifying_brew,if=!talent.chi_explosion.enabled&talent.rushing_jade_wind.enabled&stagger.moderate&buff.shuffle.remains>=6"] = {
	ID = 119582--[[Purifying Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and x.Chi >= 1 and not x.TalentChiExplosionEnabled and x.TalentRushingJadeWindEnabled and s.BuffDuration(124274--[[Moderate Stagger]], "player", nil, false, false, true) > x.Lag and x.BuffShuffleRemains >= (6 + x.Lag)
	end,
}

a.spells["blackout_kick,if=buff.shuffle.down"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.Chi >= 2 and x.BuffShuffleRemains <= x.GCD
	end,
}

a.spells["blackout_kick,if=buff.shuffle.remains<=3&cooldown.keg_smash.remains>=gcd"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.Chi >= 2 and x.BuffShuffleRemains <= (3 + x.GCD) and x.CooldownKegSmashRemains > x.GCD
	end,
}

a.spells["blackout_kick,if=talent.rushing_jade_wind.enabled&buff.shuffle.remains<=3&cooldown.keg_smash.remains>=gcd"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.Chi >= 2 and x.TalentRushingJadeWindEnabled and x.BuffShuffleRemains <= (3 + x.GCD) and x.CooldownKegSmashRemains > x.GCD
	end,
}

a.spells["blackout_kick,if=talent.rushing_jade_wind.enabled&buff.serenity.up"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.Chi >= 2 and x.TalentRushingJadeWindEnabled and x.BuffSerenityRemains > x.GCD
	end,
}

a.spells["blackout_kick,if=talent.rushing_jade_wind.enabled&chi>=4"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.Chi >= 4 and x.TalentRushingJadeWindEnabled
	end,
}

a.spells["blackout_kick,if=buff.serenity.up"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.Chi >= 2 and x.BuffSerenityRemains > x.GCD
	end,
}

a.spells["blackout_kick,if=chi>=4"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.Chi >= 4
	end,
}

a.spells["blackout_kick,if=!talent.chi_explosion.enabled&(buff.combo_breaker_bok.react|buff.serenity.up)"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.CanBlackoutKick and (s.BuffDuration(116768--[[Combo Breaker: Blackout Kick]], "player") > x.GCD or x.BuffSerenityRemains > x.GCD)
	end,
}

a.spells["blackout_kick,if=!talent.chi_explosion.enabled&chi.max-chi<2"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.CanBlackoutKick and (x.MaxChi - x.Chi) < 2
	end,
}

a.spells["blackout_kick,if=talent.rushing_jade_wind.enabled&!talent.chi_explosion.enabled&chi.max-chi<2"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.CanBlackoutKick and x.TalentRushingJadeWindEnabled and (x.MaxChi - x.Chi) < 2
	end,
}

a.spells["blackout_kick,if=talent.rushing_jade_wind.enabled&!talent.chi_explosion.enabled&(buff.combo_breaker_bok.react|buff.serenity.up)"] = {
	ID = 100784--[[Blackout Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.CanBlackoutKick and x.TalentRushingJadeWindEnabled and (s.BuffDuration(116768--[[Combo Breaker: Blackout Kick]], "player") > x.GCD or x.BuffSerenityRemains > x.GCD)
	end,
}

a.spells["chi_explosion,if=talent.chi_explosion.enabled&chi>=3&buff.combo_breaker_ce.react"] = {
	ID = 152174--[[Chi Explosion]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.Chi >= 3 and x.TalentChiExplosionEnabled and s.BuffDuration(159407--[[Combo Breaker: Chi Explosion]], "player", nil, false, false, true) > x.GCD
	end,
}

a.spells["chi_explosion,if=talent.chi_explosion.enabled&chi>=3"] = {
	ID = 152174--[[Chi Explosion]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.Chi >= 3 and x.TalentChiExplosionEnabled
	end,
}

a.spells["chi_explosion,if=chi>=4"] = {
	ID = 152174--[[Chi Explosion]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.Chi >= 4 and x.TalentChiExplosionEnabled
	end,
}

a.spells["chi_explosion,if=chi>=3"] = {
	ID = 152174--[[Chi Explosion]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return x.Chi >= 3 and x.TalentChiExplosionEnabled
	end,
}

a.spells["Nimble Brew"] = {
	ID = 137562--[[Nimble Brew]],
	NoRangeCheck = true,
	NoGCD = true,
	FlashBlink = true,
	Check = function(z)
		local eventIndex = C_LossOfControl.GetNumEvents()
		while (eventIndex > 0) do
			local locType, _, _, _, _, timeRemaining = C_LossOfControl.GetEventInfo(eventIndex)
			if (locType == "ROOT" or locType == "STUN_MECHANIC" or locType == "FEAR") and timeRemaining then
				return timeRemaining > 1.5
			end
			eventIndex = eventIndex - 1
		end
	end,
}

a.spells["Tiger's Lust"] = {
	ID = 116841--[[Tiger's Lust]],
	NoRangeCheck = true,
	FlashBlink = true,
	FlashColor = "Aqua",
	Check = function(z)
		local _, runSpeed = GetUnitSpeed("player")
		return s.HasTalent(116841--[[Tiger's Lust]]) and runSpeed / 7 * 100 < 100
	end,
}

a.spells["chi_wave,if=energy.time_to_max>2&buff.serenity.down"] = {
	ID = 115098--[[Chi Wave]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.HasTalent(115098--[[Chi Wave]]) and x.TimeToMax > (x.GCD + 2) and x.BuffSerenityRemains <= x.GCD
	end,
}

a.spells["chi_wave,if=talent.chi_wave.enabled&energy.time_to_max>3"] = {
	ID = 115098--[[Chi Wave]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.HasTalent(115098--[[Chi Wave]]) and x.TimeToMax > (x.GCD + 3)
	end,
}

a.spells["zen_sphere,cycle_targets=1,if=energy.time_to_max>2&!dot.zen_sphere.ticking&buff.serenity.down"] = {
	ID = 124081--[[Zen Sphere]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.HasTalent(124081--[[Zen Sphere]]) and x.TimeToMax > (x.GCD + 2) and s.BuffDuration(124081--[[Zen Sphere]], "player", nil, false, false, true) <= x.GCD and x.BuffSerenityRemains <= x.GCD
	end,
}

a.spells["zen_sphere,cycle_targets=1,if=!dot.zen_sphere.ticking"] = {
	ID = 124081--[[Zen Sphere]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.HasTalent(124081--[[Zen Sphere]]) and s.BuffDuration(124081--[[Zen Sphere]], "player", nil, false, false, true) <= x.GCD
	end,
}

a.spells["zen_sphere,cycle_targets=1,if=talent.zen_sphere.enabled&!dot.zen_sphere.ticking"] = {
	ID = 124081--[[Zen Sphere]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.HasTalent(124081--[[Zen Sphere]]) and s.BuffDuration(124081--[[Zen Sphere]], "player", nil, false, false, true) <= x.GCD
	end,
}

a.spells["chi_burst,if=talent.chi_burst.enabled&energy.time_to_max>2&buff.serenity.down"] = {
	ID = 123986--[[Chi Burst]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.HasTalent(123986--[[Chi Burst]]) and x.TimeToMax > (x.GCD + 2) and x.BuffSerenityRemains <= x.GCD
	end,
	NotWhileMoving = true,
}

a.spells["chi_burst,if=talent.chi_burst.enabled&energy.time_to_max>3"] = {
	ID = 123986--[[Chi Burst]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.HasTalent(123986--[[Chi Burst]]) and x.TimeToMax > (x.GCD + 3)
	end,
	NotWhileMoving = true,
}

a.spells["chi_brew,if=chi.max-chi>=2&((charges=1&recharge_time<=10)|charges=2|target.time_to_die<charges*10)&buff.tigereye_brew.stack<=16"] = {
	ID = 115399--[[Chi Brew]],
	NoRangeCheck = true,
	Check = function(z)
		local charges, maxCharges, timeLastCast, cooldownDuration = GetSpellCharges(115399--[[Chi Brew]])
		local recharge_time
		if charges < maxCharges then
			recharge_time = cooldownDuration - GetTime() + timeLastCast
		else
			recharge_time = 0
		end
		return x.ShouldTemporaryBuff and x.InCombat and s.HasTalent(115399--[[Chi Brew]]) and (x.MaxChi - x.Chi) >= 2 and ((charges == 1 and recharge_time<=10) or charges == 2 or x.TimeToDie < charges * 10) and s.BuffStack(125195--[[Tigereye Brew]], "player", nil, false, false, true) <= 16
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["chi_brew,if=talent.chi_brew.enabled&chi.max-chi>=2&buff.elusive_brew_stacks.stack<=10"] = {
	ID = 115399--[[Chi Brew]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and s.HasTalent(115399--[[Chi Brew]]) and (x.MaxChi - x.Chi) >= 2 and x.BuffElusiveBrewStacks <= 10
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["Charging Ox Wave"] = {
	ID = 119392--[[Charging Ox Wave]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.HasTalent(119392--[[Charging Ox Wave]]) and not s.MeleeDistance("target")
	end,
	FlashColor = "Pink",
}

a.spells["dampen_harm,if=incoming_damage_1500ms&buff.fortifying_brew.down&buff.elusive_brew_activated.down"] = {
	ID = 122278--[[Dampen Harm]],
	Check = function(z)
		return s.HasTalent(122278--[[Dampen Harm]]) and x.ShouldTemporaryBuff and x.InCombat and x.IncomingDamage1500ms and s.BuffDuration(115203--[[Fortifying Brew]], "player", nil, false, false, true) <= x.Lag and x.BuffElusiveBrewRemains <= x.Lag
	end,
	FlashColor = "Red",
	NoGCD = true,
	Continue = true,
}

a.spells["fortifying_brew,if=incoming_damage_1500ms&(buff.dampen_harm.down|buff.diffuse_magic.down)&buff.elusive_brew_activated.down"] = {
	ID = 115203--[[Fortifying Brew]],
	FlashColor = "Red",
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and x.IncomingDamage1500ms and s.BuffDuration(122278--[[Dampen Harm]], "player", nil, false, false, true) <= x.Lag and s.BuffDuration(122783--[[Diffuse Magic]], "player", nil, false, false, true) <= x.Lag and x.BuffElusiveBrewRemains <= x.Lag
	end,
	NoGCD = true,
	Continue = true,
}

a.spells["elusive_brew,if=buff.elusive_brew_stacks.react>=9&(buff.dampen_harm.down|buff.diffuse_magic.down)&buff.elusive_brew_activated.down"] = {
	ID = 115308--[[Elusive Brew]],
	Check = function(z)
		z.FlashBlink = false
		if x.ThreatPercent < 100 then
			z.FlashColor = "Pink"
		else
			z.FlashColor = "Yellow"
			if s.BuffStack(128939--[[Elusive Brew]], "player") == 15 then
				z.FlashBlink = true
			end
		end
		return x.ShouldTemporaryBuff and x.InCombat and x.BuffElusiveBrewStacks >= 9 and s.BuffDuration(122278--[[Dampen Harm]], "player", nil, false, false, true) <= x.Lag and s.BuffDuration(122783--[[Diffuse Magic]], "player", nil, false, false, true) <= x.Lag and x.BuffElusiveBrewRemains <= x.Lag
	end,
	NoGCD = true,
	Continue = true,
}

a.spells["Diffuse Magic"] = {
	ID = 122783--[[Diffuse Magic]],
	Check = function(z)
		return s.HasTalent(122783--[[Diffuse Magic]]) and s.Debuff(nil, "player", nil, false, true, false, "Magic")
	end,
	FlashColor = "Aqua",
	NoGCD = true,
}

a.spells["diffuse_magic,if=incoming_damage_1500ms&buff.fortifying_brew.down"] = {
	ID = 122783--[[Diffuse Magic]],
	Check = function(z)
		return s.HasTalent(122783--[[Diffuse Magic]]) and x.IncomingDamage1500ms and s.BuffDuration(115203--[[Fortifying Brew]], "player", nil, false, false, true) <= x.Lag
	end,
	FlashColor = "Red",
	NoGCD = true,
}

a.spells["Detox"] = {
	ID = 115450--[[Detox]],
	Check = function(z)
		return s.Debuff(nil, "player", nil, false, true, false, "Poison|Disease")
	end,
	FlashColor = "White",
}

a.spells["invoke_xuen,if=talent.invoke_xuen.enabled&time>5"] = {
	ID = 123904--[[Invoke Xuen, the White Tiger]],
	NoRangeCheck = true,
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.HasTalent(123904--[[Invoke Xuen, the White Tiger]]) and x.Time > 5
	end,
	Continue = true,
	FlashColor = "Purple",
}

a.spells["breath_of_fire,if=chi>=3&buff.shuffle.remains>=6&dot.breath_of_fire.remains<=gcd"] = {
	ID = 115181--[[Breath of Fire]],
	EnemyTargetNeeded = true,
	NoRangeCheck = true,
	Check = function(z)
		return x.Chi >= 3 and x.BuffShuffleRemains > (6 + x.GCD) and s.MyDebuffDuration(115181--[[Breath of Fire]], "target", nil, false, false, true) <= x.GCD
	end,
}

a.spells["rising_sun_kick,if=(debuff.rising_sun_kick.down|debuff.rising_sun_kick.remains<3)"] = {
	ID = 107428--[[Rising Sun Kick]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.Chi >= 2 and x.DebuffRisingSunKickRemains < (3 + x.GCD)
	end,
}

a.spells["rising_sun_kick,if=!talent.chi_explosion.enabled"] = {
	ID = 107428--[[Rising Sun Kick]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.Chi >= 2 and not s.HasTalent(152174--[[Chi Explosion]])
	end,
}

a.spells["rising_sun_kick,if=!talent.rushing_jade_wind.enabled&chi=chi.max"] = {
	ID = 107428--[[Rising Sun Kick]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return not x.TalentRushingJadeWindEnabled and x.Chi == x.MaxChi
	end,
}

a.spells["fists_of_fury,if=buff.energizing_brew.down&energy.time_to_max>4&buff.tiger_power.remains>4"] = {
	ID = 113656--[[Fists of Fury]],
	RequireBuff = 125359--[[Tiger Power]],
	RequireBuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	NoRangeCheck = true,
	NotWhileMoving = true,
	Check = function(z)
		local FoFDuration = (4 / (1 + (UnitSpellHaste("player") / 100)))
		z.RequireMoreBuffTime = FoFDuration
		return s.BuffDuration(115288--[[Energizing Brew]], "player") <= x.GCD and x.TimeToMax > (x.GCD + FoFDuration)
	end,
}

a.spells["fists_of_fury,if=energy.time_to_max>cast_time&buff.tiger_power.remains>cast_time&debuff.rising_sun_kick.remains>cast_time&!buff.serenity.remains"] = {
	ID = 113656--[[Fists of Fury]],
	EnemyTargetNeeded = true,
	Melee = true,
	NoRangeCheck = true,
	Check = function(z)
		z.NotWhileMoving = not s.HasGlyph(159490--[[Glyph of the Floating Butterfly]])
		local cast_time = (4 / (1 + (UnitSpellHaste("player") / 100))) + x.GCD
		return x.Chi >= 3 and x.TimeToMax > cast_time and x.BuffTigerPowerRemains > cast_time and x.DebuffRisingSunKickRemains > cast_time and x.BuffSerenityRemains <= x.GCD
	end,
}

a.spells["fists_of_fury,if=talent.rushing_jade_wind.enabled&energy.time_to_max>cast_time&buff.tiger_power.remains>cast_time&debuff.rising_sun_kick.remains>cast_time&!buff.serenity.remains"] = {
	ID = 113656--[[Fists of Fury]],
	EnemyTargetNeeded = true,
	Melee = true,
	NoRangeCheck = true,
	Check = function(z)
		z.NotWhileMoving = not s.HasGlyph(159490--[[Glyph of the Floating Butterfly]])
		local cast_time = (4 / (1 + (UnitSpellHaste("player") / 100))) + x.GCD
		return x.Chi >= 3 and x.TalentRushingJadeWindEnabled and x.TimeToMax > cast_time and x.BuffTigerPowerRemains > cast_time and x.DebuffRisingSunKickRemains > cast_time and x.BuffSerenityRemains <= x.GCD
	end,
}

a.spells["energizing_brew,if=energy.time_to_max>5"] = {
	ID = 115288--[[Energizing Brew]],
	Buff = 115288--[[Energizing Brew]],
	BuffUnit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and x.TimeToMax > (x.GCD + 5)
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["energizing_brew,if=cooldown.fists_of_fury.remains>6&(!talent.serenity.enabled|(!buff.serenity.remains&cooldown.serenity.remains>4))&energy+energy.regen*gcd<50"] = {
	ID = 115288--[[Energizing Brew]],
	Buff = 115288--[[Energizing Brew]],
	BuffUnit = "player",
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and s.SpellCooldown(113656--[[Fists of Fury]]) > (6 + x.Lag) and (not x.TalentSerenityEnabled or (x.BuffSerenityRemains <= x.Lag and s.SpellCooldown(152173--[[Serenity]]) > 4)) and x.Energy + x.EnergyPerSecond * x.GCD < 50
	end,
	FlashColor = "Yellow",
	NoGCD = true,
}

a.spells["rushing_jade_wind"] = {
	ID = 116847--[[Rushing Jade Wind]],
	NoRangeCheck = true,
	Check = function(z)
		return x.Energy >= 40 and x.ShouldTemporaryBuff and x.InCombat and x.TalentRushingJadeWindEnabled
	end,
}

a.spells["rushing_jade_wind,if=chi.max-chi>=1&talent.rushing_jade_wind.enabled"] = {
	ID = 116847--[[Rushing Jade Wind]],
	NoRangeCheck = true,
	Check = function(z)
		return x.Energy >= 40 and x.ShouldTemporaryBuff and x.InCombat and (x.MaxChi - x.Chi) >= 1 and x.TalentRushingJadeWindEnabled
	end,
}

a.spells["spinning_crane_kick,if=!talent.rushing_jade_wind.enabled"] = {
	ID = 101546--[[Spinning Crane Kick]],
	Check = function(z)
		return x.Energy >= 40 and not x.TalentRushingJadeWindEnabled
	end,
}

a.spells["spinning_crane_kick,if=chi.max-chi>=1&!talent.rushing_jade_wind.enabled"] = {
	ID = 101546--[[Spinning Crane Kick]],
	Check = function(z)
		return x.Energy >= 40 and (x.MaxChi - x.Chi) >= 1 and not x.TalentRushingJadeWindEnabled
	end,
}

a.spells["keg_smash,if=chi.max-chi>=2&!buff.serenity.remains"] = {
	ID = 121253--[[Keg Smash]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return (x.MaxChi - x.Chi) >= 2 and x.BuffSerenityRemains <= x.GCD
	end,
}

a.spells["expel_harm,if=chi.max-chi>=1&cooldown.keg_smash.remains>=gcd"] = {
	ID = 115072--[[Expel Harm]],
	EnemyTargetNeeded = false,
	Check = function(z)
		return (x.MaxChi - x.Chi) >= 1 and x.CooldownKegSmashRemains > x.GCD and s.HealthPercent("player") <= 99
	end,
	FlashID = {115072, 147489},
}

a.spells["expel_harm,if=chi.max-chi>=1&cooldown.keg_smash.remains>=gcd&(energy+(energy.regen*(cooldown.keg_smash.remains)))>=40"] = {
	ID = 115072--[[Expel Harm]],
	EnemyTargetNeeded = false,
	Check = function(z)
		return (x.MaxChi - x.Chi) >= 1 and x.CooldownKegSmashRemains > x.GCD and (x.Energy + (x.EnergyRegen * math.max(x.GCD, x.CooldownKegSmashRemains))) >= 40
	end,
	FlashID = {115072, 147489},
}

a.spells["Flying Serpent Kick"] = {
	ID = 101545--[[Flying Serpent Kick]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return not s.MeleeDistance("target")
	end,
	FlashColor = "Pink",
}

a.spells["jab,if=chi.max-chi>=1&cooldown.keg_smash.remains>=gcd&cooldown.expel_harm.remains>=gcd"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return (x.MaxChi - x.Chi) >= 1 and x.Energy >= 45 and x.CooldownKegSmashRemains > x.GCD and (s.SpellCooldown(115072--[[Expel Harm]]) > x.GCD or s.HealthPercent("player") > 99)
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["jab,if=talent.rushing_jade_wind.enabled&chi.max-chi>=1&cooldown.keg_smash.remains>=gcd&cooldown.expel_harm.remains>=gcd"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.Energy >= 45 and x.TalentRushingJadeWindEnabled and (x.MaxChi - x.Chi) >= 1 and x.CooldownKegSmashRemains > x.GCD and s.SpellCooldown(115072--[[Expel Harm]]) > x.GCD
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["jab,if=chi.max-chi>=2"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return (x.MaxChi - x.Chi) >= 2 and x.Energy >= 45
	end,
	RunLast = function(z)
		a.Flash("Expel Harm w/ Jab")
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["Expel Harm w/ Jab"] = {
	ID = 115072--[[Expel Harm]],
	EnemyTargetNeeded = false,
	Override = function(z)
		return s.HealthPercent("player") <= 90 and s.SpellCooldown(115072--[[Expel Harm]]) <= x.GCD
	end,
	FlashID = {115072, 147489},
}

a.spells["jab,if=talent.rushing_jade_wind.enabled&chi.max-chi>=2"] = {
	ID = 100780--[[Jab]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.TalentRushingJadeWindEnabled and (x.MaxChi - x.Chi) >= 2 and x.Energy >= 45
	end,
	RunLast = function(z)
		a.Flash("Expel Harm w/ Jab")
	end,
	FlashID = {100780, 115698, 108967, 130257, 108557, 115687, 115693, 115695, 125661},
}

a.spells["jade_serpent_statue"] = {
	ID = 115313--[[Jade Serpent Statue]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and GetTotemInfo(1) == false
	end,
}

a.spells["black_ox_statue"] = {
	ID = 115315--[[Black Ox Statue]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and GetTotemInfo(1) == false
	end,
}

a.spells["crackling_jade_lightning,if=buff.bloodlust.up&buff.lucidity.up"] = {
	ID = 117952--[[Crackling Jade Lightning]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.Bloodlust and x.BuffLucidityRemains > x.GCD
	end,
}

a.spells["guard"] = {
	ID = 115295--[[Guard]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and x.Chi >= 2
	end,
	FlashID = {115295--[[Guard]], 123402--[[Glyph of Guard]]},
}

a.spells["tiger_palm,if=(energy+(energy.regen*(cooldown.keg_smash.remains)))>=40"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return (x.Energy + (x.EnergyRegen * math.max(x.GCD, x.CooldownKegSmashRemains))) >= 40
	end,
}

a.spells["tiger_palm,if=talent.rushing_jade_wind.enabled&(energy+(energy.regen*(cooldown.keg_smash.remains)))>=40"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return x.TalentRushingJadeWindEnabled and (x.Energy + (x.EnergyRegen * math.max(x.GCD, x.CooldownKegSmashRemains))) >= 40
	end,
}

a.spells["tiger_palm,if=talent.rushing_jade_wind.enabled&cooldown.keg_smash.remains>=gcd"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return x.TalentRushingJadeWindEnabled and x.CooldownKegSmashRemains > x.GCD
	end,
}

a.spells["tiger_palm,if=cooldown.keg_smash.remains>=gcd"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return x.CooldownKegSmashRemains > x.GCD
	end,
}

a.spells["tiger_palm,if=buff.combo_breaker_tp.react&buff.combo_breaker_tp.remains<=2"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return x.CanTigerPalm and s.BuffDuration(118864--[[Combo Breaker: Tiger Palm]], "player", nil, false, false, true) > x.GCD and s.BuffDuration(118864--[[Combo Breaker: Tiger Palm]], "player", nil, false, false, true) <= (x.GCD + 2)
	end,
}

a.spells["tiger_palm,if=talent.rushing_jade_wind.enabled&buff.combo_breaker_tp.react&buff.combo_breaker_tp.remains<=2"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	NoPowerCheck = true,
	EvenIfNotUsable = true,
	Check = function(z)
		return x.CanTigerPalm and x.TalentRushingJadeWindEnabled and s.BuffDuration(118864--[[Combo Breaker: Tiger Palm]], "player", nil, false, false, true) > x.GCD and s.BuffDuration(118864--[[Combo Breaker: Tiger Palm]], "player", nil, false, false, true) <= (x.GCD + 2)
	end,
}

a.spells["tiger_palm,if=buff.muscle_memory.up&buff.lucidity.up"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.BuffMuscleMemoryRemains > x.GCD and x.BuffLucidityRemains > x.GCD
	end,
}

a.spells["tiger_palm,if=buff.muscle_memory.up&!buff.tiger_power.up"] = {
	ID = 100787--[[Tiger Palm]],
	Buff = 125359--[[Tiger Power]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.BuffMuscleMemoryRemains > x.GCD
	end,
}

a.spells["tiger_palm,if=buff.muscle_memory.up"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.BuffMuscleMemoryRemains > x.GCD
	end,
}

a.spells["tiger_palm,if=buff.tiger_power.remains<=3"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.CanTigerPalm and x.BuffTigerPowerRemains <= 3 + x.GCD
	end,
}

a.spells["tiger_palm,if=buff.tiger_power.down&debuff.rising_sun_kick.remains>1&energy.time_to_max>1"] = {
	ID = 100787--[[Tiger Palm]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.CanTigerPalm and x.BuffTigerPowerRemains <= x.GCD and x.DebuffRisingSunKickRemains > (x.GCD + 1) and x.TimeToMax > (x.GCD + 1)
	end,
}

a.spells["blackout_kick,if=buff.muscle_memory.up&chi>1&!buff.serpents_zeal.up"] = {
	ID = 100784--[[Blackout Kick]],
	Buff = 127722--[[Serpent's Zeal]],
	BuffUnit = "player",
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return x.BuffMuscleMemoryRemains > x.GCD and x.Chi > 1
	end,
}

a.spells["renewing_mist"] = {
	ID = 115151--[[Renewing Mist]],
	NoRangeCheck = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.InGroup() and s.InGroup() > 1
	end,
}

a.spells["uplift"] = {
	ID = 116670--[[Uplift]],
	NoRangeCheck = true,
	Check = function(z)
		if not s.InGroup() then
			return false
		end
		local group
		if s.InRaid() then
			group = "raid"
		else
			group = "party"
		end
		local mistCount = 0
		local healCount = 0
		for i= 1, GetNumGroupMembers() do
			if s.MyBuffDuration(s.SpellName(115151--[[Renewing Mist]]), group..i) > x.GCD then
				mistCount = mistCount + 1
				if s.HealthPercent(group..i) < 20 then
					healCount = healCount + 3
				elseif s.HealthPercent(group..i) < 85 then
					healCount = healCount + 1
				end
			end
		end
		return x.ShouldTemporaryBuff and (healCount >= 3 or (not s.MeleeDistance("target") and mistCount > 0 and x.Chi == x.MaxChi and x.InCombat))
	end,
}

a.spells["tigereye_brew,if=buff.tigereye_brew_use.down&buff.tigereye_brew.stack=20"] = {
	ID = 116740--[[Tigereye Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	FlashBlink = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.BuffTigereyeBrewRemains <= x.Lag and x.BuffTigereyeBrewStack == 20
	end,
}

a.spells["tigereye_brew,if=buff.tigereye_brew_use.down&buff.tigereye_brew.stack>=10&buff.serenity.up"] = {
	ID = 116740--[[Tigereye Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.BuffTigereyeBrewRemains <= x.Lag and x.BuffTigereyeBrewStack >= 10 and x.BuffSerenityRemains > x.Lag
	end,
}

a.spells["tigereye_brew,if=buff.tigereye_brew_use.down&buff.tigereye_brew.stack>=10&cooldown.fists_of_fury.up&chi>=3&debuff.rising_sun_kick.up&buff.tiger_power.up"] = {
	ID = 116740--[[Tigereye Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.BuffTigereyeBrewRemains <= x.Lag and x.BuffTigereyeBrewStack >= 10 and s.SpellCooldown(113656--[[Fists of Fury]]) <= x.GCD and x.Chi >= 3 and x.DebuffRisingSunKickRemains > x.Lag and x.BuffTigerPowerRemains > x.Lag
	end,
}

a.spells["tigereye_brew,if=talent.hurricane_strike.enabled&buff.tigereye_brew_use.down&buff.tigereye_brew.stack>=10&cooldown.hurricane_strike.up&chi>=3&debuff.rising_sun_kick.up&buff.tiger_power.up"] = {
	ID = 116740--[[Tigereye Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.HasTalent(152175--[[Hurricane Strike]]) and x.BuffTigereyeBrewRemains <= x.Lag and x.BuffTigereyeBrewStack >= 10 and s.SpellCooldown(152175--[[Hurricane Strike]]) <= x.Lag and x.Chi >= 3 and x.DebuffRisingSunKickRemains > x.Lag and x.BuffTigerPowerRemains > x.Lag
	end,
}

a.spells["tigereye_brew,if=buff.tigereye_brew_use.down&chi>=2&(buff.tigereye_brew.stack>=16|target.time_to_die<40)&debuff.rising_sun_kick.up&buff.tiger_power.up"] = {
	ID = 116740--[[Tigereye Brew]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.BuffTigereyeBrewRemains <= x.Lag and x.Chi >= 2 and (x.BuffTigereyeBrewStack >= 16 or (x.TimeToDie < 40 and not s.Dummy("target"))) and x.DebuffRisingSunKickRemains > x.Lag and x.BuffTigerPowerRemains > x.Lag
	end,
}

a.spells["mana_tea,if=buff.mana_tea.react>=2&mana.pct<=25"] = {
	ID = 115294--[[Mana Tea]],
	ConsumeBuff = 115867--[[Mana Tea]],
	ConsumeUseBuffID = true,
	ConsumeBuffUnit = "player",
	ConsumeStack = 2,
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.PowerPercent("player", SPELL_POWER_MANA) <= 25
	end,
}

a.spells["stance,choose=sturdy_ox"] = {
	Type = "form",
	ID = 115069--[[Stance of the Sturdy Ox]],
	Buff = 115069--[[Stance of the Sturdy Ox]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["stance,choose=fierce_tiger"] = {
	Type = "form",
	ID = 103985--[[Stance of the Fierce Tiger]],
	Buff = 103985--[[Stance of the Fierce Tiger]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["stance,choose=wise_serpent"] = {
	Type = "form",
	ID = 115070--[[Stance of the Wise Serpent]],
	Buff = 115070--[[Stance of the Wise Serpent]],
	BuffUnit = "player",
	FlashColor = "Green",
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["Legacy of the Emperor"] = {
	ID = 115921--[[Legacy of the Emperor]],
	NoRangeCheck = true,
	FlashColor = "Green",
	Buff = a.StatBuffs,
	BuffUnit = "raid",
	UseBuffID = true,
	EarlyRefresh = 300,
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["Legacy of the White Tiger"] = {
	ID = 116781--[[Legacy of the White Tiger]],
	NoRangeCheck = true,
	FlashColor = "Green",
	Buff1 = a.CritBuffs,
	BuffUnit1 = "raid",
	UseBuffID1 = true,
	EarlyRefresh1 = 300,
	Buff2 = a.StatBuffs,
	BuffUnit2 = "raid",
	UseBuffID2 = true,
	EarlyRefresh2 = 300,
	Check = function(z)
		return x.ShouldPermanentBuff
	end,
}

a.spells["Spear Hand Strike"] = {
	ID = 116705--[[Spear Hand Strike]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	NoGCD = true,
	FlashColor = "Aqua",
}

a.spells["Paralysis"] = {
	ID = 115078--[[Paralysis]],
	EnemyTargetNeeded = true,
	Interrupt = 1,
	Check = function(z)
		return not s.Boss("target")
	end,
	FlashColor = "Aqua",
}

a.spells["Leg Sweep as Interrupt"] = {
	ID = 119381--[[Leg Sweep]],
	EnemyTargetNeeded = true,
	Interrupt = true,
	Melee = true,
	Check = function(z)
		return s.HasTalent(119381--[[Leg Sweep]]) and not s.Boss("target")
	end,
	FlashColor = "Aqua",
}

a.spells["leg_sweep"] = {
	ID = 119381--[[Leg Sweep]],
	EnemyTargetNeeded = true,
	Melee = true,
	Check = function(z)
		return s.HasTalent(119381--[[Leg Sweep]]) and not s.Boss("target")
	end,
	Continue = true,
}

a.spells["Provoke"] = {
	ID = 115546--[[Provoke]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return s.Form(115069--[[Stance of the Sturdy Ox]]) and x.ThreatPercent <= 99 and ( GetNumGroupMembers() > 1 or GetNumSubgroupMembers() > 0 ) and x.InCombat
	end,
	NoGCD = true,
	FlashColor = "Purple",
}

a.spells["Clash"] = {
	ID = 122057--[[Clash]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Yellow",
}

a.spells["Roll"] = {
	ID = 109132--[[Roll]],
	EnemyTargetNeeded = true,
	Check = function(z)
		return not s.MeleeDistance("target")
	end,
	NoGCD = true,
	FlashColor = "Pink",
}

a.spells["Dizzying Haze"] = {
	ID = 115180--[[Dizzying Haze]],
	Debuff = 115180--[[Dizzying Haze]],
	EnemyTargetNeeded = true,
	NoRangeCheck = true,
	FlashColor = "Blue",
}

a.spells["touch_of_death,if=target.health.percent<10"] = {
	ID = 115080--[[Touch of Death]],
	Check = function(z)
		return s.HealthPercent("target") < 10 and x.Chi >= 3
	end,
}

a.spells["flask,type=greater_draenic_stamina_flask"] = {
	Type = "item",
	ID = 109160--[[Greater Draenic Stamina Flask]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss() and s.BuffDuration(156084--[[Greater Draenic Stamina Flask]], "player", nil, false, false, true) < 300
	end,
	FlashColor = "Yellow",
}

a.spells["flask,type=greater_draenic_agility_flask"] = {
	Type = "item",
	ID = 109153--[[Greater Draenic Agility Flask]],
	EnemyTargetNeeded = true,
	NoGCD = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and s.Boss() and s.BuffDuration(156064--[[Greater Draenic Agility Flask]], "player", nil, false, false, true) < 300
	end,
	FlashColor = "Yellow",
}

a.spells["serenity,if=talent.serenity.enabled&chi>=2&buff.tiger_power.up&debuff.rising_sun_kick.up"] = {
	ID = 152173--[[Serenity]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.TalentSerenityEnabled and x.Chi >= 2 and x.BuffTigerPowerRemains > x.Lag and x.DebuffRisingSunKickRemains > x.Lag
	end,
}

a.spells["serenity,if=talent.serenity.enabled&energy<=40"] = {
	ID = 152173--[[Serenity]],
	NoGCD = true,
	FlashColor = "Yellow",
	Continue = true,
	Check = function(z)
		return x.ShouldTemporaryBuff and x.InCombat and s.HasTalent(152173--[[Serenity]]) and x.Energy <= 40
	end,
}

a.spells["hurricane_strike,if=talent.hurricane_strike.enabled&energy.time_to_max>cast_time&buff.tiger_power.remains>cast_time&debuff.rising_sun_kick.remains>cast_time&buff.energizing_brew.down"] = {
	ID = 152175--[[Hurricane Strike]],
	Check = function(z)
		return x.Chi >= 3 and s.HasTalent(152175--[[Hurricane Strike]]) and x.TimeToMax > (2 + x.GCD) and x.BuffTigerPowerRemains > (2 + x.GCD) and x.DebuffRisingSunKickRemains > (2 + x.GCD) and not s.BuffDuration(115288--[[Energizing Brew]], "player", nil, false, false, true) <= x.GCD
	end,
}

a.spells["hurricane_strike,if=talent.rushing_jade_wind.enabled&talent.hurricane_strike.enabled&energy.time_to_max>cast_time&buff.tiger_power.remains>cast_time&debuff.rising_sun_kick.remains>cast_time&buff.energizing_brew.down"] = {
	ID = 152175--[[Hurricane Strike]],
	Check = function(z)
		return x.Chi >= 3 and x.TalentRushingJadeWindEnabled and s.HasTalent(152175--[[Hurricane Strike]]) and x.TimeToMax > (2 + x.GCD) and x.BuffTigerPowerRemains > (2 + x.GCD) and x.DebuffRisingSunKickRemains > (2 + x.GCD) and not s.BuffDuration(115288--[[Energizing Brew]], "player", nil, false, false, true) <= x.GCD
	end,
}